@@ -6,12 +6,12 @@ use std::{
 
 use floem::{
     peniko::{
-        kurbo::{Point, Rect},
         Color,
+        kurbo::{Point, Rect},
     },
     reactive::{
-        create_memo, create_rw_signal, Memo, ReadSignal, RwSignal, Scope, SignalGet,
-        SignalUpdate, SignalWith,
+        Memo, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        create_memo, create_rw_signal,
     },
     views::editor::id::EditorId,
 };
@@ -19,12 +19,12 @@ use lapce_rpc::plugin::VoltID;
 use serde::{Deserialize, Serialize};
 
 use crate::{
-    config::{color::LapceColor, icon::LapceIcons, LapceConfig},
+    config::{LapceConfig, color::LapceColor, icon::LapceIcons},
     doc::{Doc, DocContent},
     editor::{
+        EditorData, EditorInfo,
         diff::{DiffEditorData, DiffEditorInfo},
         location::EditorLocation,
-        EditorData, EditorInfo,
     },
     id::{
         DiffEditorId, EditorTabId, KeymapId, SettingsId, SplitId,
@@ -306,8 +306,10 @@ impl EditorTabChild {
                             is_pristine,
                         )
                     }
-                    [Some((left_path, left_is_pristine)), Some((right_path, right_is_pristine))] =>
-                    {
+                    [
+                        Some((left_path, left_is_pristine)),
+                        Some((right_path, right_is_pristine)),
+                    ] => {
                         let (svg, color) =
                             config.files_svg(&[&left_path, &right_path]);
                         let [left_file_name, right_file_name] =
@@ -468,7 +470,7 @@ impl EditorTabData {
     }
 
     pub fn tab_info(&self, data: &WindowTabData) -> EditorTabInfo {
-        let info = EditorTabInfo {
+        EditorTabInfo {
             active: self.active,
             is_focus: data.main_split.active_editor_tab.get_untracked()
                 == Some(self.editor_tab_id),
@@ -477,7 +479,6 @@ impl EditorTabData {
                 .iter()
                 .map(|(_, _, child)| child.child_info(data))
                 .collect(),
-        };
-        info
+        }
     }
 }
