@@ -4,22 +4,23 @@ use std::{
     path::PathBuf,
     rc::Rc,
     sync::{
-        atomic::{AtomicU64, Ordering},
         Arc,
+        atomic::{AtomicU64, Ordering},
+        mpsc::{Receiver, Sender, TryRecvError, channel},
     },
     time::Instant,
 };
 
 use anyhow::Result;
-use crossbeam_channel::{Receiver, Sender, TryRecvError};
 use floem::{
     ext_event::{create_ext_action, create_signal_from_channel},
     keyboard::Modifiers,
     reactive::{
-        use_context, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate,
-        SignalWith,
+        ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        use_context,
     },
 };
+use im::Vector;
 use itertools::Itertools;
 use lapce_core::{
     buffer::rope_text::RopeText, command::FocusCommand, language::LapceLanguage,
@@ -44,10 +45,10 @@ use crate::{
     db::LapceDb,
     debug::{RunDebugConfigs, RunDebugMode},
     editor::{
-        location::{EditorLocation, EditorPosition},
         EditorData,
+        location::{EditorLocation, EditorPosition},
     },
-    keypress::{condition::Condition, KeyPressData, KeyPressFocus},
+    keypress::{KeyPressData, KeyPressFocus, condition::Condition},
     lsp::path_from_url,
     main_split::MainSplitData,
     source_control::SourceControlData,
@@ -58,7 +59,7 @@ use crate::{
 pub mod item;
 pub mod kind;
 
-const DEFAULT_RUN_TOML: &str = include_str!("../../defaults/run.toml");
+pub const DEFAULT_RUN_TOML: &str = include_str!("../../defaults/run.toml");
 
 #[derive(Clone, PartialEq, Eq)]
 pub enum PaletteStatus {
@@ -139,7 +140,7 @@ impl PaletteData {
         let run_id = cx.create_rw_signal(0);
         let run_id_counter = Arc::new(AtomicU64::new(0));
 
-        let (run_tx, run_rx) = crossbeam_channel::unbounded();
+        let (run_tx, run_rx) = channel();
         {
             let run_id = run_id.read_only();
             let input = input.read_only();
@@ -154,7 +155,11 @@ impl PaletteData {
                     let run_id = run_id.get_untracked();
                     let preselect_index =
                         preselect_index.try_update(|i| i.take()).unwrap();
-                    let _ = tx.send((run_id, input.input, items, preselect_index));
+                    if let Err(err) =
+                        tx.send((run_id, input.input, items, preselect_index))
+                    {
+                        tracing::error!("{:?}", err);
+                    }
                 });
             }
             // this effect only monitors input change
@@ -166,16 +171,21 @@ impl PaletteData {
                 }
                 let items = items.get_untracked();
                 let run_id = run_id.get_untracked();
-                let _ = tx.send((run_id, input.input, items, None));
+                if let Err(err) = tx.send((run_id, input.input, items, None)) {
+                    tracing::error!("{:?}", err);
+                }
                 kind
             });
         }
-        let (resp_tx, resp_rx) = crossbeam_channel::unbounded();
+        let (resp_tx, resp_rx) = channel();
         {
             let run_id = run_id_counter.clone();
-            std::thread::spawn(move || {
-                Self::update_process(run_id, run_rx, resp_tx);
-            });
+            std::thread::Builder::new()
+                .name("PaletteUpdateProcess".to_owned())
+                .spawn(move || {
+                    Self::update_process(run_id, run_rx, resp_tx);
+                })
+                .unwrap();
         }
         let (filtered_items, set_filtered_items) =
             cx.create_signal(im::Vector::new());
@@ -361,6 +371,7 @@ impl PaletteData {
             PaletteKind::File | PaletteKind::DiffFiles => {
                 self.get_files();
             }
+            PaletteKind::HelpAndFile => self.get_palette_help_and_file(),
             PaletteKind::Line => {
                 self.get_lines();
             }
@@ -410,7 +421,12 @@ impl PaletteData {
 
     /// Initialize the palette with a list of the available palette kinds.
     fn get_palette_help(&self) {
-        let items = PaletteKind::iter()
+        let items = self.get_palette_help_items();
+        self.items.set(items);
+    }
+
+    fn get_palette_help_items(&self) -> Vector<PaletteItem> {
+        PaletteKind::iter()
             .filter_map(|kind| {
                 // Don't include PaletteHelp as the user is already here.
                 (kind != PaletteKind::PaletteHelp)
@@ -437,13 +453,18 @@ impl PaletteData {
                     indices: vec![],
                 }
             })
-            .collect();
-
-        self.items.set(items);
+            .collect()
     }
 
-    /// Initialize the palette with the files in the current workspace.
-    fn get_files(&self) {
+    fn get_palette_help_and_file(&self) {
+        let help_items: Vector<PaletteItem> = self.get_palette_help_items();
+        self.get_files_and_prepend(Some(help_items));
+    }
+
+    // get the files in the current workspace
+    // and prepend items if prepend is some
+    // e.g. help_and_file
+    fn get_files_and_prepend(&self, prepend: Option<im::Vector<PaletteItem>>) {
         let workspace = self.workspace.clone();
         let set_items = self.items.write_only();
         let send =
@@ -470,7 +491,12 @@ impl PaletteData {
                         }
                     })
                     .collect::<im::Vector<_>>();
-                set_items.set(items);
+                let mut new_items = im::Vector::new();
+                if let Some(prepend) = prepend {
+                    new_items.append(prepend);
+                }
+                new_items.append(items);
+                set_items.set(new_items);
             });
         self.common.proxy.get_files(move |result| {
             if let Ok(ProxyResponse::GetFilesResponse { items }) = result {
@@ -479,6 +505,11 @@ impl PaletteData {
         });
     }
 
+    /// Initialize the palette with the files in the current workspace.
+    fn get_files(&self) {
+        self.get_files_and_prepend(None);
+    }
+
     /// Initialize the palette with the lines in the current document.
     fn get_lines(&self) {
         let editor = self.main_split.active_editor.get_untracked();
@@ -1610,12 +1641,14 @@ impl PaletteData {
                     items,
                     &mut matcher,
                 ) {
-                    let _ = resp_tx.send((
+                    if let Err(err) = resp_tx.send((
                         current_run_id,
                         input,
                         filtered_items,
                         preselect_index,
-                    ));
+                    )) {
+                        tracing::error!("{:?}", err);
+                    }
                 }
             } else {
                 return;
