@@ -3,10 +3,12 @@ pub mod data;
 pub mod debug_view;
 pub mod document_symbol;
 pub mod global_search_view;
+pub mod implementation_view;
 pub mod kind;
 pub mod plugin_view;
 pub mod position;
 pub mod problem_view;
+pub mod references_view;
 pub mod source_control_view;
 pub mod style;
 pub mod terminal_view;
