@@ -1,18 +1,19 @@
 use std::{path::PathBuf, rc::Rc};
 
 use floem::{
+    View,
     action::show_context_menu,
     event::{Event, EventListener},
     menu::{Menu, MenuItem},
     peniko::kurbo::Rect,
-    reactive::{create_memo, create_rw_signal, SignalGet, SignalUpdate, SignalWith},
+    prelude::SignalTrack,
+    reactive::{SignalGet, SignalUpdate, SignalWith, create_memo, create_rw_signal},
     style::{CursorStyle, Style},
     views::{
-        container, dyn_stack,
-        editor::view::{cursor_caret, LineRegion},
-        label, scroll, stack, svg, text, Decorators,
+        Decorators, container, dyn_stack,
+        editor::view::{LineRegion, cursor_caret},
+        label, scroll, stack, svg, text,
     },
-    View,
 };
 use lapce_core::buffer::rope_text::RopeText;
 use lapce_rpc::source_control::FileDiff;
@@ -230,15 +231,13 @@ fn file_diffs_view(source_control: SourceControlData) -> impl View {
             .to_string();
         let style_path = path.clone();
         stack((
-            checkbox(move || checked, config)
-                .style(|s| s.hover(|s| s.cursor(CursorStyle::Pointer)))
-                .on_click_stop(move |_| {
-                    file_diffs.update(|diffs| {
-                        if let Some((_, checked)) = diffs.get_mut(&full_path) {
-                            *checked = !*checked;
-                        }
-                    });
-                }),
+            checkbox(move || checked, config).on_click_stop(move |_| {
+                file_diffs.update(|diffs| {
+                    if let Some((_, checked)) = diffs.get_mut(&full_path) {
+                        *checked = !*checked;
+                    }
+                });
+            }),
             svg(move || config.get().file_svg(&path).0).style(move |s| {
                 let config = config.get();
                 let size = config.ui.icon_size() as f32;
@@ -338,6 +337,7 @@ fn file_diffs_view(source_control: SourceControlData) -> impl View {
                 .padding_right(10.0 + size + 6.0)
                 .width_pct(100.0)
                 .items_center()
+                .cursor(CursorStyle::Pointer)
                 .hover(|s| {
                     s.background(config.color(LapceColor::PANEL_HOVERED_BACKGROUND))
                 })
