@@ -1,16 +1,16 @@
 use std::{collections::HashMap, path::PathBuf, rc::Rc, sync::Arc};
 
 use alacritty_terminal::{
+    Term,
     grid::{Dimensions, Scroll},
     selection::{Selection, SelectionType},
-    term::{test::TermSize, TermMode},
+    term::{TermMode, test::TermSize},
     vi_mode::ViMotion,
-    Term,
 };
 use anyhow::anyhow;
 use floem::{
     keyboard::{Key, KeyEvent, Modifiers, NamedKey},
-    reactive::{RwSignal, Scope, SignalGet, SignalUpdate},
+    reactive::{RwSignal, Scope, SignalGet, SignalUpdate, SignalWith},
     views::editor::text::SystemClipboard,
 };
 use lapce_core::{
@@ -32,8 +32,8 @@ use super::{
 };
 use crate::{
     command::{CommandExecuted, CommandKind, InternalCommand},
-    debug::RunDebugProcess,
-    keypress::{condition::Condition, KeyPressFocus},
+    debug::{RunDebugMode, RunDebugProcess},
+    keypress::{KeyPressFocus, condition::Condition},
     window_tab::CommonData,
     workspace::LapceWorkspace,
 };
@@ -376,13 +376,10 @@ impl TerminalData {
         let mut profile = profile.unwrap_or_default();
 
         if profile.workdir.is_none() {
-            profile.workdir = if let Ok(path) = url::Url::from_file_path(
+            profile.workdir = url::Url::from_file_path(
                 workspace.path.as_ref().cloned().unwrap_or_default(),
-            ) {
-                Some(path)
-            } else {
-                None
-            };
+            )
+            .ok();
         }
 
         let exp_run_debug = run_debug
@@ -420,7 +417,11 @@ impl TerminalData {
 
         {
             let raw = raw.clone();
-            let _ = common.term_tx.send((term_id, TermEvent::NewTerminal(raw)));
+            if let Err(err) =
+                common.term_tx.send((term_id, TermEvent::NewTerminal(raw)))
+            {
+                tracing::error!("{:?}", err);
+            }
             common.proxy.new_terminal(term_id, profile);
         }
 
@@ -742,6 +743,20 @@ impl TerminalData {
             .proxy
             .terminal_resize(self.term_id, width, height);
     }
+
+    pub fn stop(&self) {
+        if let Some(dap_id) = self.run_debug.with_untracked(|x| {
+            if let Some(process) = x {
+                if !process.is_prelaunch && process.mode == RunDebugMode::Debug {
+                    return Some(process.config.dap_id);
+                }
+            }
+            None
+        }) {
+            self.common.proxy.dap_stop(dap_id);
+        }
+        self.common.proxy.terminal_close(self.term_id);
+    }
 }
 
 /// [`RunDebugConfig`] with expanded out program/arguments/etc. Used for creating the terminal.
@@ -783,15 +798,27 @@ impl ExpandedRunDebug {
             } else {
                 (run_debug.program.clone(), run_debug.args.clone())
             };
-
-        let program = if program == "${lapce}" {
-            std::env::current_exe().map_err(|e| {
-                anyhow!("Failed to get current exe for ${{lapce}} run and debug: {e}")
-            })?.to_str().ok_or_else(|| anyhow!("Failed to convert ${{lapce}} path to str"))?.to_string()
+        let mut program = if program == "${lapce}" {
+            std::env::current_exe()
+                .map_err(|e| {
+                    anyhow!(
+                        "Failed to get current exe for ${{lapce}} run and debug: {e}"
+                    )
+                })?
+                .to_str()
+                .ok_or_else(|| anyhow!("Failed to convert ${{lapce}} path to str"))?
+                .to_string()
         } else {
             program
         };
 
+        if program.contains("${workspace}") {
+            if let Some(workspace) = workspace.path.as_ref().and_then(|x| x.to_str())
+            {
+                program = program.replace("${workspace}", workspace);
+            }
+        }
+
         if let Some(args) = &mut args {
             for arg in args {
                 // Replace all mentions of ${workspace} with the current workspace path
